==> slayersbeasts-fabric-1.21.1-5.2.0-sources.jar: net/invictusslayer/slayersbeasts/world/level/block/PeatBlock.java <==
package net.invictusslayer.slayersbeasts.world.level.block;

import com.mojang.serialization.MapCodec;
import net.invictusslayer.slayersbeasts.data.tags.SBTags;
import net.minecraft.class_10;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_1540;
import net.minecraft.class_1922;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2346;
import net.minecraft.class_2350;
import net.minecraft.class_2398;
import net.minecraft.class_243;
import net.minecraft.class_259;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_3532;
import net.minecraft.class_3726;
import net.minecraft.class_3727;
import net.minecraft.class_5819;

public class PeatBlock extends class_2346 {
	public static final MapCodec<PeatBlock> CODEC = method_54094(PeatBlock::new);

	public PeatBlock(class_2251 properties) {
		super(properties);
	}

	protected MapCodec<? extends class_2346> method_53969() {
		return field_46280;
	}

	public void method_9548(class_2680 state, class_1937 level, class_2338 pos, class_1297 entity) {
		if (!(entity instanceof class_1309) || entity.method_25936().method_27852(this)) {
			entity.method_5844(state, new class_243(0.4D, 0.4D, 0.4D));
			if (level.field_9236) {
				class_5819 random = level.method_8409();
				boolean flag = entity.field_6038 != entity.method_23317() || entity.field_5989 != entity.method_23321();
				if (flag && random.method_43048(10) == 0) {
					level.method_8406(class_2398.field_11233, entity.method_23317(), pos.method_10264() + 1, entity.method_23321(), class_3532.method_32750(random, -1.0F, 1.0F) / 12, 0.05D, class_3532.method_32750(random, -1.0F, 1.0F) / 12);
				}
			}
		}

		entity.method_33572(false);
	}

	public boolean method_9522(class_2680 state, class_2680 adjacentState, class_2350 direction) {
		return adjacentState.method_27852(this) || super.method_9522(state, adjacentState, direction);
	}

	public class_265 method_9571(class_2680 state, class_1922 level, class_2338 pos) {
		return class_259.method_1073();
	}

	public class_265 method_26159(class_2680 state, class_1922 level, class_2338 pos, class_3726 context) {
		return class_259.method_1073();
	}

	public class_265 method_9549(class_2680 state, class_1922 level, class_2338 pos, class_3726 context) {
		if (context instanceof class_3727 entitycollisioncontext) {
			class_1297 entity = entitycollisioncontext.method_32480();
			if (entity != null) {
				if (entity instanceof class_1540) {
					return super.method_9549(state, level, pos, context);
				}

				if (entity.field_6017 > 2.5F) {
					return class_259.method_1081(0.0D, 0.0D, 0.0D, 1.0D, 0.9D, 1.0D);
				}

				if (entity.method_5864().method_20210(SBTags.EntityTypes.PEAT_WALKABLE_MOBS) && context.method_16192(class_259.method_1077(), pos, false) && !context.method_16193()) {
					return super.method_9549(state, level, pos, context);
				}
			}
		}

		return class_259.method_1073();
	}

	public boolean method_9516(class_2680 state, class_10 type) {
		return true;
	}
}

==> slayersbeasts-fabric-1.21.4-6.2.0-sources.jar: net/invictusslayer/slayersbeasts/world/level/block/PeatBlock.java <==
package net.invictusslayer.slayersbeasts.world.level.block;

import com.mojang.serialization.MapCodec;
import net.invictusslayer.slayersbeasts.data.tags.SBTags;
import net.minecraft.class_10;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_1540;
import net.minecraft.class_1922;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2346;
import net.minecraft.class_2350;
import net.minecraft.class_2398;
import net.minecraft.class_243;
import net.minecraft.class_259;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_3532;
import net.minecraft.class_3726;
import net.minecraft.class_3727;
import net.minecraft.class_5819;

public class PeatBlock extends class_2346 {
	public static final MapCodec<PeatBlock> CODEC = method_54094(PeatBlock::new);

	public PeatBlock(class_2251 properties) {
		super(properties);
	}

	protected MapCodec<? extends class_2346> method_53969() {
		return field_46280;
	}

	public void method_9548(class_2680 state, class_1937 level, class_2338 pos, class_1297 entity) {
		if (!(entity instanceof class_1309) || entity.method_25936().method_27852(this)) {
			entity.method_5844(state, new class_243(0.4D, 0.4D, 0.4D));
			if (level.field_9236) {
				class_5819 random = level.method_8409();
				boolean flag = entity.field_6038 != entity.method_23317() || entity.field_5989 != entity.method_23321();
				if (flag && random.method_43048(10) == 0) {
					level.method_8406(class_2398.field_11233, entity.method_23317(), pos.method_10264() + 1, entity.method_23321(), class_3532.method_32750(random, -1.0F, 1.0F) / 12, 0.05D, class_3532.method_32750(random, -1.0F, 1.0F) / 12);
				}
			}
		}

		entity.method_33572(false);
	}

	public boolean method_9522(class_2680 state, class_2680 adjacentState, class_2350 direction) {
		return adjacentState.method_27852(this) || super.method_9522(state, adjacentState, direction);
	}

	public class_265 method_9571(class_2680 state) {
		return class_259.method_1073();
	}

	public class_265 method_26159(class_2680 state, class_1922 level, class_2338 pos, class_3726 context) {
		return class_259.method_1073();
	}

	public class_265 method_9549(class_2680 state, class_1922 level, class_2338 pos, class_3726 context) {
		if (context instanceof class_3727 entitycollisioncontext) {
			class_1297 entity = entitycollisioncontext.method_32480();
			if (entity != null) {
				if (entity instanceof class_1540) {
					return super.method_9549(state, level, pos, context);
				}

				if (entity.field_6017 > 2.5F) {
					return class_259.method_1081(0.0D, 0.0D, 0.0D, 1.0D, 0.9D, 1.0D);
				}

				if (entity.method_5864().method_20210(SBTags.EntityTypes.PEAT_WALKABLE_MOBS) && context.method_16192(class_259.method_1077(), pos, false) && !context.method_16193()) {
					return super.method_9549(state, level, pos, context);
				}
			}
		}

		return class_259.method_1073();
	}

	public boolean method_9516(class_2680 state, class_10 type) {
		return true;
	}
}
